==> pwebb-0.0.5.tar.gz: pwebb-0.0.5/README.md <==
### In the name of God, the Most Gracious, the Most Merciful.

# PWebB
Python Web Boot (PWebB). PWebB is a DRY full-stack framework based on Flask micro web framework.


<br/><br/><br/>
## Documentation

### Install and update using [pip](https://pip.pypa.io/en/stable/getting-started/):
```bash
pip install -U pwebb
```

### Create project using CLI
```bash
pwebcli project init -n <specify_project_name>
```
It will automatically create a project with the name. For example the project name is **example** then it will create
an example directory and initialize the project in it.

### Run the project 
```bash
cd <specify_project_name>

# If windows then active the virtual environment using below command
venv\Scripts\activate

# For Linux or MacOS
source venv\bin\activate

# Run project using below command
python pweb_app.py
```
The project will run in http://127.0.0.1:1212



<br/><br/>

**Please find [the Documentation]() with example from [hmtmcse.com/pwebb]()**


<br/><br/><br/>
## Donate
[Problem Fighter](https://www.problemfighter.com/) develops and supports PWeb and the libraries it uses. In order to grow
the community of contributors and users, and allow the maintainers to devote more time to the projects.

<a target="_blank" href="https://www.buymeacoffee.com/problemfighter" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me Us Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>


<br/><br/><br/>
## Contributing
For guidance on setting up a development environment and how to make a contribution to PWeb, see the contributing guidelines.


<br/><br/><br/>
## Links
* **Changes :** [https://opensource.problemfighter.org/pweb/pweb](https://opensource.problemfighter.org/pweb/pweb)
* **PyPI Releases :** [https://pypi.org/project/pwebb](https://pypi.org/project/pwebb)
* **Source Code :** [https://github.com/problemfighter/pweb](https://github.com/problemfighter/pweb)
* **Issue Tracker :** [https://github.com/problemfighter/pweb/issues](https://github.com/problemfighter/pweb/issues)
* **Website :** [https://www.problemfighter.com/open-source](https://www.problemfighter.com/open-source)

==> pwebb-0.0.11.tar.gz: pwebb-0.0.11/README.md <==
### In the name of God, the Most Gracious, the Most Merciful.

# PWebB
Python Web Boot (PWebB). PWebB is a DRY full-stack framework based on Flask micro web framework.


<br/><br/><br/>
## Documentation

### Install and update using [pip](https://pip.pypa.io/en/stable/getting-started/):
```bash
pip install -U pwebb
```

### Create project using CLI
```bash
pwebcli project init -n <specify_project_name>
```
It will automatically create a project with the name. For example the project name is **example** then it will create
an example directory and initialize the project in it.

### Run the project 
```bash
cd <specify_project_name>

# If windows then active the virtual environment using below command
venv\Scripts\activate

# For Linux or MacOS
source venv\bin\activate

# Run project using below command
python pweb_app.py
```
The project will run in http://127.0.0.1:1212



<br/><br/>

**Please find [the Documentation]() with example from [hmtmcse.com/pwebb]()**


<br/><br/><br/>
## Donate
[Bangla Fighter](https://www.banglafighter.com/) develops and supports PWeb and the libraries it uses. In order to grow
the community of contributors and users, and allow the maintainers to devote more time to the projects.

<a target="_blank" href="https://www.buymeacoffee.com/banglafighter" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me Us Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>


<br/><br/><br/>
## Contributing
For guidance on setting up a development environment and how to make a contribution to PWeb, see the contributing guidelines.


<br/><br/><br/>
## Links
* **Changes :** [https://opensource.banglafighter.org/pweb/pweb](https://opensource.banglafighter.org/pweb/pweb)
* **PyPI Releases :** [https://pypi.org/project/pwebb](https://pypi.org/project/pwebb)
* **Source Code :** [https://github.com/banglafighter/pweb](https://github.com/banglafighter/pweb)
* **Issue Tracker :** [https://github.com/banglafighter/pweb/issues](https://github.com/banglafighter/pweb/issues)
* **Website :** [https://www.problemfighter.com/open-source](https://www.problemfighter.com/open-source)
